@@ -85,9 +85,12 @@ class prefilters:
 
 @dataclass
 class prefilters_v2:
+    reason_codes: list
     col_reason_codes: str = "reason_codes"
     col_reason_code_01: str = "reason_code_01"
     col_reason_code_02: str = "reason_code_02"
+    col_user_cnt: str = "userid"
+    col_underwriting_decision: str = "underwriting_decision"
     reason_codes_len: int = 20
 
     def _hit(self, x, prefilter_code):
@@ -114,7 +117,7 @@ class prefilters_v2:
         function to check if a reason code is the only reaon code exist in the reason code string
         """
 
-        if prefilter_code == x[self.col_reason_code_01] and x[self.col_reason_code_02].isnull():
+        if prefilter_code == x[self.col_reason_code_01] and x[self.col_reason_code_02]=="":
             return True
         else:
             return False
@@ -138,6 +141,7 @@ class prefilters_v2:
         """
         split_col_names = self._generate_split_col_names()
 
+        df[self.col_reason_codes] = df[self.col_reason_codes].apply(lambda x: ast.literal_eval(str(x))) #convert string list col to list col
         df[split_col_names] = pd.DataFrame(df[self.col_reason_codes].tolist(), index=df.index)
         return df 
 
